# LOICA

Welcome to the LOICA (Logical Operators for Integrated Cell Algorithms) repository, our Python package for designing, modeling and characterizing genetic networks.

<img src="https://github.com/RudgeLab/LOICA/blob/master/images/LOICA_Logo.svg#gh-light-mode-only" alt="LOICA logo" width="250"/>
<img src="https://github.com/RudgeLab/LOICA/blob/master/images/LOICA_Logo_night.svg#gh-dark-mode-only" alt="LOICA night logo" width="250"/>


![PyPI](https://img.shields.io/pypi/v/loica)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/loica)
![PyPI - License](https://img.shields.io/pypi/l/loica)

As you may have noticed, our logo features a beautiful bird—loica _[(Leistes loyca)](https://en.wikipedia.org/wiki/Long-tailed_meadowlark)_; a bird native to Chile known for its particular red chest and legendary kindness, with which we share name[.](https://youtu.be/qDL3zhB8-MM)

## Instalation

Installing LOICA is way easier than pronuncing it! 

Do:

`pip install loica`

For more details please refer to our [Wiki](https://github.com/RudgeLab/LOICA/wiki) for installation instructions adn developer guides.

## LOICA allows you to:

- Compile Code into DNA fragments that execute Cell Algorithms
- Easy programation of genetic network models
- Generation of synthetic data
- Communicate with Flapjack
- Use and output SBOL files
- Use all sorts of cellular computation
- Easy, fluid and customisable DNA design

## Tutorials

Now that you have LOICA installed you can familiarize yourself with the tool using the [Jupyter notebook tutorials](https://github.com/RudgeLab/LOICA/tree/master/notebooks) designed for this purpose.

## Class Diagram
<img src="https://github.com/RudgeLab/LOICA/blob/master/images/LOICA%20class%20diagram3.png" alt="LOICA class diagram" width="800"/>
